@@ -1,4 +1,4 @@
-#line 2 methmakename(__FILE__)
+#line 2 methmakename(code_1arg_h)
 
 static void
 THIS_OP_NAME(const char *from_s, char *to_s, int dim, carray_form from_form, carray_form to_form)
